@@ -17,6 +17,7 @@ class file_options:
         self.set_pipeline_steps(gui=gui)
         self.set_directories()
         self.simulation_parameters(inflow=inflow)
+        self.rom_parameters()
 
     def set_geometry_options(self,number_samples=50,use_distance_alignment_method=True):
         geometry_options = {'number_samples':                number_samples,
@@ -201,16 +202,29 @@ class file_options:
             directory_constructor['create_main_folder'] = True
         else:
             directory_constructor['create_main_folder'] = False
-        directory_constructor['main_folder'] = outdir+'/CCO_DATA'
-        number = len(glob.glob(directory_constructor['main_folder']+'/CCO_*'))
-        directory_constructor['data_folder'] = directory_constructor['main_folder']+'/simulation_data{}'.format(number)
-        directory_constructor['mesh_complete_folder'] = directory_constructor['data_folder']+'/mesh-complete'
-        directory_constructor['mesh_surfaces_folder'] = directory_constructor['mesh_complete_folder']+'/mesh-surfaces'
-        directory_constructor['centerline_folder'] = directory_constructor['data_folder']+'/centerlines'
-        directory_constructor['postprocessing_folder'] = directory_constructor['data_folder']+'/post'
+        directory_constructor['main_folder'] = outdir+os.sep+'CCO_DATA'
+        number = len(glob.glob(directory_constructor['main_folder']+os.sep+'CCO_*'))
+        directory_constructor['data_folder'] = directory_constructor['main_folder']+os.sep+'simulation_data{}'.format(number)
+        directory_constructor['mesh_complete_folder'] = directory_constructor['data_folder']+os.sep+'mesh-complete'
+        directory_constructor['mesh_surfaces_folder'] = directory_constructor['mesh_complete_folder']+os.sep+'mesh-surfaces'
+        directory_constructor['centerline_folder'] = directory_constructor['data_folder']+os.sep+'centerlines'
+        directory_constructor['postprocessing_folder'] = directory_constructor['data_folder']+os.sep+'post'
+        directory_constructor['rom_folder'] = directory_constructor['data_folder']+os.sep+'rom'
+        directory_constructor['rom_0D_folder'] = directory_constructor['rom_folder']+os.sep+'zeroD'
+        directory_constructor['rom_1D_folder'] = directory_constructor['rom_folder']+os.sep+'oneD'
+        directory_constructor['main_folder']           = directory_constructor['main_folder'].replace('\\','\\\\')
+        directory_constructor['data_folder']           = directory_constructor['data_folder'].replace('\\','\\\\')
+        directory_constructor['mesh_complete_folder']  = directory_constructor['mesh_complete_folder'].replace('\\','\\\\')
+        directory_constructor['mesh_surfaces_folder']  = directory_constructor['mesh_surfaces_folder'].replace('\\','\\\\')
+        directory_constructor['centerline_folder']     = directory_constructor['centerline_folder'].replace('\\','\\\\')
+        directory_constructor['postprocessing_folder'] = directory_constructor['postprocessing_folder'].replace('\\','\\\\')
+        directory_constructor['rom_folder']            = directory_constructor['rom_folder'].replace('\\','\\\\')
+        directory_constructor['rom_0D_folder']         = directory_constructor['rom_0D_folder'].replace('\\','\\\\')
+        directory_constructor['rom_1D_folder']         = directory_constructor['rom_1D_folder'].replace('\\','\\\\')
         self.directory_constructor = directory_constructor
         self.number = number
-        self.filename = directory_constructor['main_folder']+'/CCO_{}.py'.format(number)
+        self.filename = directory_constructor['main_folder']+os.sep+'CCO_{}.py'.format(number)
+        self.filename = self.filename.replace('\\','\\\\')
         self.name = 'CCO_{}'.format(number)
         return
 
@@ -325,3 +339,19 @@ class file_options:
         self.solver_constructor      = solver_constructor
         self.postsolver_constructor  = postsolver_constructor
         return
+
+    def rom_parameters(self,zeroD=True,oneD=True,time_step=0.001,
+                       number_time_steps=1000):
+        rom0D_constructor = {'create': zeroD,
+                             'model_order': 0,
+                             'time_step': time_step,
+                             'number_time_steps': number_time_steps}
+
+        rom1D_constructor = {'create': oneD,
+                             'model_order': 1,
+                             'time_step': time_step,
+                             'number_time_steps': number_time_steps}
+
+        self.rom_constructor = {'0D': rom0D_constructor,
+                                '1D': rom1D_constructor}
+        return
